package com.pointrlabs.sample.splash;

import android.os.Bundle;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import com.pointrlabs.core.BuildConfig;
import com.pointrlabs.core.management.Pointr;
import com.pointrlabs.core.management.interfaces.PointrListener;
import com.pointrlabs.core.nativecore.wrappers.Plog;
import com.pointrlabs.sample.R;
import com.pointrlabs.sample.selection.SelectionActivity;

/**
 * Activity to show loading spinner until [Pointr] is ready.
 * This is the launcher activity for the sample
 */
public class PointrLoadingActivity extends AppCompatActivity implements PointrListener {

    private PointrProgressSpinner progressSpinner;
    private TextView textViewStatus;

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_splash);
        progressSpinner = findViewById(R.id.progressSpinner);
        textViewStatus = findViewById(R.id.textViewStatus);

        final Pointr pointr = Pointr.getPointr();
        assert pointr != null;
        pointr.start();
        pointr.addListener(this);
        Plog.i("Pointr SDK version: " + BuildConfig.VERSION_NAME);
        textViewStatus.setText(pointr.getState().toString());
        if (pointr.getState() == Pointr.State.RUNNING) {
            startSelectionActivity();
        }
    }

    @Override
    public void onStart() {
        super.onStart();
        progressSpinner.show();
    }

    @Override
    public void onStop() {
        super.onStop();
        progressSpinner.hide();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        assert Pointr.getPointr() != null;
        Pointr.getPointr().removeListener(this);
    }

    @Override
    public void onStateUpdated(Pointr.State state) {
        runOnUiThread(() -> {
            textViewStatus.setText(state.toString());
            Toast.makeText(this, state.toString(), Toast.LENGTH_SHORT).show();
        });

        if (state == Pointr.State.RUNNING) {
            startSelectionActivity();
        }
    }

    private void startSelectionActivity() {
        runOnUiThread(() -> {
            startActivity(SelectionActivity.newIntent(this));
            finish();
        });
    }
}